@@ -29,10 +29,15 @@
 
 static unsigned char sense[128];
 
+int debug = 1;
+
 bool submit_cmd(int fd, unsigned char *cdb, unsigned cdb_len, unsigned char *buf, unsigned buf_len, int dxfer_dir)
 {
 	sg_io_hdr_t hdr;
 
+	if (debug)
+		cdb_dump(cdb, cdb_len);
+
 	memset(&hdr, 0, sizeof(hdr));
 
 	hdr.interface_id = 'S';
@@ -48,8 +53,6 @@ bool submit_cmd(int fd, unsigned char *cdb, unsigned cdb_len, unsigned char *buf
 	hdr.pack_id = 0;
 	hdr.usr_ptr = 0;
 
-	printf("sbp: %p\n", hdr.sbp);
-
 	ssize_t ret = write(fd, &hdr, sizeof(hdr));
 	return ret == sizeof(hdr);
 }
@@ -77,8 +80,10 @@ bool read_response_buf(int fd, unsigned char **sensep, unsigned *sense_len, unsi
 		*sensep = sense;
 		*sense_len = hdr.sb_len_wr;
 
-		printf("sense data:\n");
-                sense_dump(sense, hdr.sb_len_wr);
+		if (debug) {
+			printf("sense data:\n");
+			sense_dump(sense, hdr.sb_len_wr);
+		}
 	}
 	if (buf_read)
 		*buf_read = hdr.dxfer_len - hdr.resid;
