@@ -3,6 +3,8 @@
 
 #include <stdio.h>
 
+extern int debug;
+
 /** Do the command that we want to test on the open disk interface. */
 void do_command(int fd);
 bool submit_cmd(int fd, unsigned char *cdb, unsigned cdb_len, unsigned char *buf, unsigned buf_len, int dxfer_dir);
@@ -13,6 +15,4 @@ static inline bool read_response(int fd, unsigned char **sense, unsigned *sense_
 	return read_response_buf(fd, sense, sense_len, NULL);
 }
 
-void response_dump(unsigned char *buf, int buf_len);
-
 #endif
