@@ -15,7 +15,10 @@
  */
 
 #include "scsicmd.h"
+#include "scsicmd_utils.h"
+
 #include "main.h"
+#include "sense_dump.h"
 #include <stdio.h>
 #include <memory.h>
 #include <errno.h>
@@ -26,12 +29,6 @@
 #include <scsi/sg.h>
 #include <inttypes.h>
 
-static inline uint16_t get_uint16(unsigned char *buf, int start)
-{
-	return (uint16_t)buf[start] << 8 |
-		   (uint16_t)buf[start+1];
-}
-
 static void dump_page(int fd, uint8_t page, uint8_t subpage)
 {
 	unsigned char cdb[32];
